--[[
	author: Zax
	content:
		functions: ChatKeys.
		globals: CK_
		XML: Ck_
		XML UI: Ck_ui_
		event frame: Ck_ui_eventFrame
		XML config: Ck_cfg_
	todo :
--]]

---------------------------------------------------------------------------------------
------------------------------------- VARIABLES ---------------------------------------
ChatKeys = {} -- prefixe fonctions
local addonName = ...

local addonVar = { -- 3 niveaux max
	["name"] = addonName, -- nécessaire
	["version"] = tonumber(GetAddOnMetadata(addonName, "Version")), -- nécessaire
	["chatColor"] = "0BDBAC", -- nécessaire
	["slashCmd"] = "chatkeys", -- nécessaire
	["settingsPanel"] = "Ck_cfg_frame", -- nom du frame de settings : laisser vide si utilisation du frame de WoW
	["minimap"] = "", -- nécessite le fichier _minimap.lua (laisser vide ou NIL si pas de bouton minimap)
}

local globalStrings = {} -- pour HOOK noms

function ChatKeys.getLocal(key) -- pour traduction (voir localization.lua) : ne pas deplacer !!!
	if (CK_LOCAL_TBL[key] == nil) then return key else return CK_LOCAL_TBL[key] end
end

----------------------------------------- saved et init
CK_SAVED = {}

function ChatKeys.initData()
	local tbl = {
		["version"] = addonVar["version"],
		["debug"] = 0,
		["defBuddyName"] = "",
		["defChannelName1"] = "",
		["defChannelName2"] = "",
		["defChannelName3"] = "",
		["defSound"] = 1,
		["defPartyNum"] = 1,
		["defShortPrefixes"] = 0,
	}
	return tbl
end

---------------------------------------------------------------------------------------
--------------------------------------- EVENTS ----------------------------------------

function ChatKeys.eventHandler(self,event,...)
	if (event == "PLAYER_LOGIN") then
		ChatKeys.chargement();
	elseif (event == "CHAT_MSG_WHISPER") then
		ChatKeys.murmureRecu(...);
	elseif (event == "CHAT_MSG_RAID") then
		ChatKeys.raidConversation(arg1,arg2,arg3);
	end;
end

---------------------------------------------------------------------------------------
--------------------------------- CHARGEMENT & BINDINGS -------------------------------

function ChatKeys.chargement()
	-------------------------------- slash commandes
	SlashCmdList["CK_CMD"] = ChatKeys.slashCmd
		SLASH_CK_CMD1 = "/chatkeys"

	-------------------------------- bindings
	BINDING_HEADER_CHATKEYS_TITLE = addonName
	
	BINDING_NAME_SAYMESSAGE = ChatKeys.getLocal("Say")
	BINDING_NAME_YELLMESSAGE = ChatKeys.getLocal("Yell")
	BINDING_NAME_INSTANCEMESSAGE = ChatKeys.getLocal("Instance or Party")
	BINDING_NAME_PARTYMESSAGE = ChatKeys.getLocal("Party")
	BINDING_NAME_RAIDMESSAGE = ChatKeys.getLocal("Raid")
	BINDING_NAME_BGDEFMESSAGE = ChatKeys.getLocal("BattleGround or LocalDefense")
	BINDING_NAME_RWRAIDMESSAGE = ChatKeys.getLocal("Raid warning")
	BINDING_NAME_GUILDMESSAGE = ChatKeys.getLocal("Guild")
	BINDING_NAME_GUILDOFFMESSAGE = ChatKeys.getLocal("Guild officers")
	
	BINDING_NAME_GENERALMESSAGE = ChatKeys.getLocal("General - 1")
	BINDING_NAME_TRADEMESSAGE = ChatKeys.getLocal("Trade - 2")
	--BINDING_NAME_DEFENSEMESSAGE = ChatKeys.getLocal("LocalDefense - 3")
	--BINDING_NAME_GROUPMESSAGE = ChatKeys.getLocal("LookingForGroup - 4")

	BINDING_NAME_SHOWCHATUI = ChatKeys.getLocal("ChatKeys Options")
	BINDING_NAME_CUSTOMMESSAGE = ChatKeys.getLocal("Whisper to your friend")
	BINDING_NAME_CUSTOMCHANNEL1 = ChatKeys.getLocal("Custom channel #1")
	BINDING_NAME_CUSTOMCHANNEL2 = ChatKeys.getLocal("Custom channel #2")
	BINDING_NAME_CUSTOMCHANNEL3 = ChatKeys.getLocal("Custom channel #3")
	BINDING_NAME_CKEMOTE = ChatKeys.getLocal("Emote")
	BINDING_NAME_CKWHISPER = ChatKeys.getLocal("Whisper to target")
	
	------------------------------- settings
	if (ChatKeys.isEmpty(CK_SAVED)) then
		CK_SAVED = ChatKeys.initData()
		ChatKeys.testPrint("=== no lua file : INIT SETTINGS ===")
	else
		local tbl = ChatKeys.initData()
		if (ChatKeys.tableKeyDiff(tbl, CK_SAVED, "") ~= nil) then
			CK_SAVED = ChatKeys.copyTable(tbl, false)
			ChatKeys.testPrint("=== diff saved data : INIT SETTINGS ===")
		end
	end
	ChatKeys.getGlobalStrings() -- initialisation HOOK
	if (CK_SAVED["shortPrefixes"] == 1) then ChatKeys.shortenGlobalStrings() end
	
	------------------------------ suite
	---------- settings panel (voir fichier _settings.lua)
	if (not ChatKeys.isEmpty(addonVar["settingsPanel"])) then ChatKeys.settingsPanelUpdate() end
	local str = ChatKeys.getLocal("loaded.")--.." "..ChatKeys.getLocal("Type /chatkeys to display settings panel.")
	
	if (ChatKeys.debug()) then
		SetCVar("scriptErrors", 1)
		--ChatKeys.echoTable(CK_SAVED, true, "   ")
		str = str..ChatKeys.getTxtColor(" -- DEBUG ON.", "orange")
	end
	ChatKeys.echoChatAppl(str, true, nil)
end

---------------------------------------------------------------------------------------
-------------------------------------- SLASH CMD --------------------------------------
function ChatKeys.slashCmd(arg, execLevel)
	ChatKeys.slashCmd_Lib(arg, execLevel)
end

function ChatKeys.slashCmd_getList(arg2) -- liste des commandes-slash (voir .lib)
	-- .slashCmd_showList(dontPrint) -- print la liste en print, ou la renvoit en chaine avec dontPrint à true (pour frame cfg)
	local tbl = {
		["user"] = {
			{
				["cmd"] = {"msg", "message"},
				["func"] = function() ChatKeys.msgCanal(arg2) end,
				["label"] = ChatKeys.getLocal("CHAN_NAME | CHAN_NUMBER -- start a message on the given channel, if available"),
			},
			{
				["cmd"] = {"w", "whisp"},
				["func"] = function() ChatKeys.wPlayer(arg2) end,
				["label"] = ChatKeys.getLocal("PLAYER_NAME -- start a whisp to the given player"),
			},
			{
				["cmd"] = {"reset"},
				["func"] = function() ChatKeys.reset() end,
				["label"] = ChatKeys.getLocal("reset options to default"),
			},
		},
		["dev"] = {
			{
				["cmd"] = {"debug"},
				["func"] = function() ChatKeys.toggleDebug() end,
				["label"] = "toggle debug",
			},
			{
				["cmd"] = {"settings"},
				["func"] = function() ChatKeys.printAddonSettings() end,
				["label"] = ChatKeys.getLocal("print addon settings"),
			},
			{
				["cmd"] = {"test"},
				["func"] = function() ChatKeys.fcnTest(arg2) end,
				["label"] = ChatKeys.getLocal("DEV test with 1 argument"),
			},
			{
				["cmd"] = {"show"},
				["func"] = function() ChatKeys.showCfgUI() end,
				["label"] = "default command",
			},
			{
				["cmd"] = {"help"},
				["func"] = function() ChatKeys.help() end,
				["label"] = "compatibility command",
			},
		},
		["DEFAULTCMD"] = "show", -- commande par défaut
		["DEFAULTARG"] = "help", -- argument par défaut d'une commande
	}
	return tbl
end

---------------------------------------------------------------------------------------
--------------------------------------- ACTIONS ---------------------------------------
function ChatKeys.help()
	ChatKeys.echoChatAppl(ChatKeys.getLocal("Type /chatkeys to display settings panel."), true, nil)
end

function ChatKeys.fcnTest(arg) --$$$
	print("------------------------------------------")
	print(date("%Y.%m.%d %H:%M:%S", GetServerTime()))
	local version, build, datevers, tocversion = GetBuildInfo()
	print(version, build, datevers, "toc = "..tocversion)
	print("------------------------------------------")
	
	local groupe = ChatKeys.isInGroupe()
	if (groupe == 2) then
		ChatKeys.echoChatAppl("en instance", false, "orange")
	elseif (groupe == 1) then
		ChatKeys.echoChatAppl("en groupe", false, "orange")
	else
		ChatKeys.echoChatAppl("NON groupé", false, "orange")
	end
end

function ChatKeys.printAddonSettings()
	ChatKeys.echoTable(CK_SAVED, "========== CK_SAVED ==========", false, "   ");
	ChatKeys.echo("================================");
end

function ChatKeys.toggleDebug() -- pour dev
	if (ChatKeys.isTrue(CK_SAVED["debug"])) then
		CK_SAVED["debug"] = 0
	else
		CK_SAVED["debug"] = 1
	end
	ChatKeys.echoChatAppl("debug "..ChatKeys.booleanToON(ChatKeys.debug())..".", false, "orange")
end

function ChatKeys.reset()
	wipe(CK_SAVED)
	CK_SAVED = ChatKeys.initData()
	
	local success, errorMessage = pcall(ChatKeys.settingsUpdate) -- si panel Settings ouvert
	
	if (ChatKeys.debug()) then ChatKeys.echoTable(CK_SAVED, false, "___"); end;
	ChatKeys.echoChatAppl(ChatKeys.getLocal("Settings reset to defaults."), false, "yellow")
end

---------------------------------------------------------------------------------------
-------------------------------------- SETTINGS ---------------------------------------

function ChatKeys.showCfgUI()
	if (Settings ~= nil) then -- wow10
		local settingsCategoryID = _G[addonVar["settingsPanel"]].categoryID -- voir fichier _settings.lua
		Settings.OpenToCategory(settingsCategoryID) -- ouverture option panel directe
	else -- classic
		InterfaceAddOnsList_Update()
		InterfaceOptionsFrame_OpenToCategory(addonName)
	end
end

---------------------------------------------------------------------------------------
------------------------------------ MURMURE RECU -------------------------------------
function ChatKeys.murmureRecu()
	if (CK_SAVED["sndNotification"] == 1) then PlaySound(1204) end -- "PutdownGems" OU PlaySound(3081) end -- "TellMessage"
end

---------------------------------------------------------------------------------------
-------------------------- NUMERO GROUPE AFFICHE EN RAID ------------------------------
function ChatKeys.raidConversation(arg1,arg2,arg3)
	-- si raidParleur = raid leader : utiliser "CHAT_MSG_RAID_LEADER" ??? (meme syntaxe)
	if (CK_SAVED["displayPartyNumber"] == 1) then
		local raidParleur = arg2
		local nom,rank,subgroup
		for i = 1,GetNumGroupMembers(),1 do
			nom,rank,subgroup = GetRaidRosterInfo(i)
			if (nom == raidParleur) then
				CHAT_RAID_GET = "["..subgroup.."]%s:\32"; -- Raid message from player %s
				return
			end
		end
	end
	CHAT_RAID_GET = "%s:\32"; -- Raid message from player %s-- ???
end

---------------------------------------------------------------------------------------
------------------------------------ FCNS INTERNES ------------------------------------

function ChatKeys.tapeMessage(prefixe)
	ChatFrame_OpenChat(prefixe)
	------- tape le debut du message dans la Chat Box pour ouvrir un canal
	--[[
	if (not ChatFrameEditBox:IsVisible()) then
		ChatFrame_OpenChat(prefixe);
	else
		ChatFrameEditBox:SetText(prefixe);
	end;
	--]]
	ChatEdit_ParseText(ChatFrame1.editBox,0)
end

function ChatKeys.msgCanal(nomCanalVoulu)
	--------- commence un msg sur le canal voulu (nom ou numero)
	if (nomCanalVoulu ~= nil) then
		local numCanal = ChatKeys.chercheCanal(nomCanalVoulu); -- cherchage de l'index du canal voulu par son nom ou son index
		ChatKeys.testPrint("Requested channel: '"..nomCanalVoulu.."'---Found channel="..numCanal.."-----", false, "grey")
		if (numCanal > 0) then
			ChatKeys.tapeMessage("/"..tostring(numCanal).." ")
		else
			ChatKeys.echoChatAppl(": "..ChatKeys.getLocal("Unable to find channel: ")..nomCanalVoulu, false, "orange")
		end
	else
		ChatKeys.echoChatAppl(": "..ChatKeys.getLocal("Unable to find channel: ").."NIL", false, "orange")
	end
end

function ChatKeys.chercheCanal(refCanal)
	-------- scanne les canaux de 1 a 10 pour trouver le numero du canal voulu (renvoit ce numero ou 0)
	local idCanal = 0
	local nomCanal = nil
	
	if (type(refCanal) == "number") then
		idCanal,nomCanal = GetChannelName(refCanal);
		ChatKeys.testPrint("search channel with ID="..refCanal.."--->>> found ID="..idCanal.."---NAME="..tostring(nomCanal).."---")
	else
		local i
		for i = 1,10,1 do
			idCanal,nomCanal = GetChannelName(i);
			ChatKeys.testPrint("searching '"..tostring(refCanal).."' INDEX "..i..": found ID="..tostring(idCanal).."---NAME="..tostring(nomCanal).."---")
			if (idCanal > 0 and nomCanal ~= nil and string.find(nomCanal,refCanal,1,true) ~= nil) then	
				ChatKeys.testPrint("found ID="..idCanal.."---NAME="..nomCanal.."---@INDEX="..i.."---")
				return idCanal
			end
		end
	end
	return idCanal
end

function ChatKeys.isInGroupe()
	if (GetNumGroupMembers(LE_PARTY_CATEGORY_INSTANCE) > 0) then
		return 2 -- Instance
	elseif (GetNumGroupMembers(LE_PARTY_CATEGORY_HOME) > 0) then
		return 1 -- Party (ou raid)
	else
		return 0 -- non groupé
	end
end

function ChatKeys.getRaidRank() -- renvoit le rank dans le raid : 2 pour RL, et 1 pour RA
	if (ChatKeys.inRaid()) then
		local playerName = UnitName("player")
		for i = 1, MAX_RAID_MEMBERS do
			local name, rank = GetRaidRosterInfo(i)
			if (name == playerName) then return rank end
		end
	end
	return 0
end

function ChatKeys.msgInstance()
	----------- commence un msg sur le canal Instance, ou Raid, ou Party
	if (ChatKeys.inInstance()) then
		ChatKeys.tapeMessage("/i ")
	elseif (ChatKeys.inParty(false)) then
		ChatKeys.tapeMessage("/p ")
	else
		ChatKeys.echoChatAppl(ChatKeys.getLocal("You are not grouped!"), false, "orange")
	end;
end

function ChatKeys.msgParty()
	----------- commence un msg sur le canal Party
	if (ChatKeys.inParty(false)) then
		ChatKeys.tapeMessage("/p ")
	else
		ChatKeys.echoChatAppl(ChatKeys.getLocal("You are not in party!"), false, "orange")
	end
end

function ChatKeys.msgRaid()
	----------- commence un msg sur le canal Raid, ou Instance, ou Party
	if (ChatKeys.inRaid()) then
		ChatKeys.tapeMessage("/ra ")
	else
		ChatKeys.msgInstance()
	end
end

function ChatKeys.warningRaid()
	----------- commence un msg sur le canal Avertissement Raid
	if (ChatKeys.inRaid()) then
		if (ChatKeys.getRaidRank() >= 1) then
			ChatKeys.tapeMessage("/rw ")
		else
			ChatKeys.echoChatAppl(ChatKeys.getLocal("You are not raid assist or leader!"), false, "orange")
		end
	else
		ChatKeys.echoChatAppl(ChatKeys.getLocal("You are not in raid!"), false, "orange")
	end
end

function ChatKeys.bgDef()
	------------ commence un msg sur le canal BG ou DefenseLocale
	if (UnitInBattleground("player") ~= nil) then
		ChatKeys.tapeMessage("/bg ");
	else
		ChatKeys.msgCanal(3); -- v4.00 ChatKeys.msgCanal(ChatKeys.getLocal("LocalDefense - 3"));
	end
end

function ChatKeys.msgGuild()
	----------- commence un msg sur le canal Guilde
	if (GetGuildInfo("player") ~= nil) then
		ChatKeys.tapeMessage("/g ")
	else
		ChatKeys.echoChatAppl(ChatKeys.getLocal("You are not member of a guild!"), false, "orange")
	end
end

function ChatKeys.msgGuildOff()
	------------ commence un msg sur le canal Guilde en tant qu'officier
	local guildName, guildRankName ,guildRankIndex = GetGuildInfo("player");
	if (guildName ~= nil) then
		ChatKeys.tapeMessage("/o ")
	else
		ChatKeys.echoChatAppl(ChatKeys.getLocal("You are not member of a guild!"), false, "orange")
	end;
end

function ChatKeys.wPlayer(nomJoueur)
	------------ commence un murmure au joueur dont le nom est defini dans l'UI d'options ou passe par slash-cmd
	local playerName = "";
	if (nomJoueur ~= nil) then -- slash-command
		playerName = nomJoueur;
	else
		if (not ChatKeys.isEmpty(CK_SAVED) and not ChatKeys.isEmpty(CK_SAVED["buddyName"])) then playerName = CK_SAVED["buddyName"]; end;
	end;
	
	if (playerName ~= "") then
		ChatKeys.tapeMessage("/w "..playerName.." ");
	else
		ChatKeys.echoChatAppl(ChatKeys.getLocal("Your friend is not defined! Open the settings panel by typing /chatkeys."), false, "orange")
	end;
end

function ChatKeys.msgCanalPerso(numPerso)
	------------ commence un message dans le canal perso dont le nom est definit dans l'UI d'options
	local numChanPerso = ChatKeys.strToNumber(numPerso);
	if (numChanPerso < 1 or numChanPerso > 3) then
		ChatKeys.echoChatAppl("#"..ChatKeys.videSiNul(numChanPerso).." "..ChatKeys.getLocal("This channel is not defined! Open the settings panel by typing /chatkeys."), false, "orange")
	else
		if (numChanPerso == 2) then
			if (CK_SAVED["channelName2"] == nil or CK_SAVED["channelName2"] == "") then
				ChatKeys.echoChatAppl(": #2 "..ChatKeys.getLocal("This channel is not defined! Open the settings panel by typing /chatkeys."), false, "orange")
			else
				ChatKeys.msgCanal(CK_SAVED["channelName2"]);
			end;
		elseif (numChanPerso == 3) then
			if (CK_SAVED["channelName3"] == nil or CK_SAVED["channelName3"] == "") then
				ChatKeys.echoChatAppl(": #3 "..ChatKeys.getLocal("This channel is not defined! Open the settings panel by typing /chatkeys."), false, "orange")
			else
				ChatKeys.msgCanal(CK_SAVED["channelName3"]);
			end;
		else
			if (CK_SAVED["channelName1"] == nil or CK_SAVED["channelName1"] == "") then
				ChatKeys.echoChatAppl(": #1 "..ChatKeys.getLocal("This channel is not defined! Open the settings panel by typing /chatkeys."), false, "orange")
			else
				ChatKeys.msgCanal(CK_SAVED["channelName1"]);
			end;
		end;
	end;
end

function ChatKeys.wTarget()
	------------ commence un murmure au joueur ami selectionne
	if ((UnitName("target") ~= nil) and (UnitIsPlayer("target")) and (UnitIsFriend("player","target"))) then
		ChatKeys.tapeMessage("/w "..UnitName("target").." ");
	else
		ChatKeys.echoChatAppl(ChatKeys.getLocal("Unable to whisper to the target."), false, "orange")
	end;
end

function ChatKeys.msgEmote()
	------------ commence un emote
	ChatKeys.tapeMessage("/em ");
end

---------------------------------------------------------------------------------------
------------------------------------- LIB DEDIEE --------------------------------------

function ChatKeys.debug() -- raccourci : renvoit true si debug ON
	return ChatKeys.isTrue(CK_SAVED["debug"])
end

function ChatKeys.getVar(nomVar, subLvl1, subLvl2) -- nécessite addonVar
	-- get valeurs de la table locale addonVar
	-- si aucun argument n'est passé, renvoit la table addonVar
	if (addonVar == nil) then return nil end
	
	if (subLvl2 ~= nil) then
		if (addonVar[nomVar][subLvl1][subLvl2] ~= nil) then return addonVar[nomVar][subLvl1][subLvl2] end
	elseif (subLvl1 ~= nil) then
		if (addonVar[nomVar][subLvl1] ~= nil) then return addonVar[nomVar][subLvl1] end
	elseif (nomVar ~= nil) then
		if (addonVar[nomVar] ~= nil) then return addonVar[nomVar] end
	else
		return addonVar
	end
end

function ChatKeys.setVar(nomVar, valeur) -- nécessite addonVar
	if (addonVar == nil) then return nil end
	if (nomVar ~= nil) then
		if (addonVar[nomVar] ~= nil) then addonVar[nomVar] = valeur end
	end
end

function ChatKeys.getSavedSettings(perCharacterBoolean) -- pour appel depuis autres fichiers
	if (perCharacterBoolean) then return CK_SAVED else return CK_SAVED end
end

---------------------------------------------------------------------------------------
--------------------------------------- HOOK ------------------------------------------
function ChatKeys.getGlobalStrings()
	globalStrings["CHAT_GUILD_GET"] = CHAT_GUILD_GET;
	globalStrings["CHAT_OFFICER_GET"] = CHAT_OFFICER_GET;
	globalStrings["CHAT_RAID_LEADER_GET"] = CHAT_RAID_LEADER_GET;
	globalStrings["CHAT_BATTLEGROUND_LEADER_GET"] = CHAT_BATTLEGROUND_LEADER_GET;
	globalStrings["CHAT_RAID_WARNING_GET"] = CHAT_RAID_WARNING_GET;
	globalStrings["CHAT_PARTY_GET"] = CHAT_PARTY_GET;
	globalStrings["CHAT_PARTY_LEADER_GET"] = CHAT_PARTY_LEADER_GET;
	globalStrings["CHAT_PARTY_GUIDE_GET"] = CHAT_PARTY_GUIDE_GET;
	globalStrings["CHAT_WHISPER_GET"] = CHAT_WHISPER_GET;
	globalStrings["CHAT_WHISPER_INFORM_GET"] = CHAT_WHISPER_INFORM_GET;
end

function ChatKeys.shortenGlobalStrings()
	CHAT_GUILD_GET = "%s:\32"; -- Guild message from player %s
	CHAT_OFFICER_GET = "[OFF] %s:\32"; -- Officers guild message from officer %s
	CHAT_RAID_LEADER_GET = "[LEAD] %s:\32"; -- Raid leader message from raid officer %s
	CHAT_BATTLEGROUND_LEADER_GET = "[LEAD] %s:\32"; -- Raid leader message from raid officer %s
	CHAT_RAID_WARNING_GET = "[ATT] %s:\32"; -- Raid alert message from raid officer %s
	CHAT_PARTY_GET = "%s:\32"; -- Party message from player %s
	CHAT_PARTY_LEADER_GET = "[LEAD] %s:\32"; -- Party leader message from player %s
	CHAT_PARTY_GUIDE_GET = "[GUI] %s:\32"; -- Party guide message from player %s
	CHAT_WHISPER_GET = ChatKeys.getLocal("From").." %s:\32"; -- Whisper from player %s
	CHAT_WHISPER_INFORM_GET = ChatKeys.getLocal("To").." %s:\32"; -- A whisper already sent to player %s
	
	CHAT_RAID_GET = "[R] %s:\32"; -- Raid message from player %s -- v 4.14
end

function ChatKeys.restoreGlobalStrings()
	CHAT_GUILD_GET = globalStrings["CHAT_GUILD_GET"];
	CHAT_OFFICER_GET = globalStrings["CHAT_OFFICER_GET"];
	CHAT_RAID_LEADER_GET = globalStrings["CHAT_RAID_LEADER_GET"];
	CHAT_BATTLEGROUND_LEADER_GET = globalStrings["CHAT_BATTLEGROUND_LEADER_GET"];
	CHAT_RAID_WARNING_GET = globalStrings["CHAT_RAID_WARNING_GET"];
	CHAT_PARTY_GET = globalStrings["CHAT_PARTY_GET"];
	CHAT_PARTY_LEADER_GET = globalStrings["CHAT_PARTY_LEADER_GET"];
	CHAT_PARTY_GUIDE_GET = globalStrings["CHAT_PARTY_GUIDE_GET"];
	CHAT_WHISPER_GET = globalStrings["CHAT_WHISPER_GET"];
	CHAT_WHISPER_INFORM_GET = globalStrings["CHAT_WHISPER_INFORM_GET"];
end

--[[ Changing current global strings
--CHAT_FLAG_AFK = "[AFK] ";
--CHAT_FLAG_DND = "[DND] ";
--CHAT_FLAG_GM = "[GM] ";

CHAT_GUILD_GET = "%s:\32"; -- Guild message from player %s
CHAT_OFFICER_GET = "[OFF] %s:\32"; -- Officers guild message from officer %s
CHAT_RAID_LEADER_GET = "[LEAD] %s:\32"; -- Raid leader message from raid officer %s
CHAT_BATTLEGROUND_LEADER_GET = "[LEAD] %s:\32"; -- Raid leader message from raid officer %s
CHAT_RAID_WARNING_GET = "[ATT] %s:\32"; -- Raid alert message from raid officer %s
--CHAT_RAID_GET = "%s:\32"; -- Raid message from player %s
CHAT_PARTY_GET = "%s:\32"; -- Party message from player %s
CHAT_PARTY_LEADER_GET = "[LEAD] %s:\32"; -- Party leader message from player %s
CHAT_PARTY_GUIDE_GET = "[GUI] %s:\32"; -- Party guide message from player %s
CHAT_WHISPER_GET = ChatKeys.getLocal("From").." %s:\32"; -- Whisper from player %s
CHAT_WHISPER_INFORM_GET = ChatKeys.getLocal("To").." %s:\32"; -- A whisper already sent to player %s
--]]